.. currentmodule:: pyscenarios

What's New
==========

.. _whats-new.0.2.0:

v0.2.0 (2019-04-29)
-------------------

- Type annotations
- 'rng' parameter in copula functions is now case insensitive
- Work around regression in IT copula with dask >= 1.1
  (`dask#4739 <https://github.com/dask/dask/issues/4739>`_)
- Smaller binary package; simplified setup
- Explicit CI tests for Windows, Python 3.5.0, and Python 3.7
- Mandatory flake8 and mypy in CI
- Changed license to Apache 2.0


.. _whats-new.0.1.0:

v0.1.0 (2018-05-27)
-------------------

Initial release.